*********
Changelog
*********

This project follows the guidelines of `Keep a changelog`_ and adheres to
`Semantic versioning`_.

.. _Keep a changelog: http://keepachangelog.com/
.. _Semantic versioning: https://semver.org/

`0.1.2`_ - 2020-10-14
=====================

Fixed
-----
* Minor documentation issues.

Added
-----
* Conversion parameter ``match_exactly``.
* Named unit Hertz.


`0.1.1`_ - 2020-06-16
=====================

Fixed
-----
* Minor documentation issues.


`0.1.0`_ - 2020-06-03
=====================

Added
-----
* Initial implementation.


.. _0.1.2: https://github.com/emtpb/united/releases/tag/0.1.2
.. _0.1.1: https://github.com/emtpb/united/releases/tag/0.1.1
.. _0.1.0: https://github.com/emtpb/united/releases/tag/0.1.0
